#
# pg_secured::controls::postgresql_audit_extension_pgaudit_is_enabled
#
# @summary The PostgreSQL Audit Extension (pgAudit) provides detailed session and/or object
# audit logging via the standard PostgreSQL logging facility. The goal of pgAudit
# is to provide PostgreSQL users with the capability to produce audit logs often
# required to comply with government, financial, or ISO certifications.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/pg_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 3.2
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 3.2
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 3.2
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 3.2
# - [Postgres Database 14 CIS V1.0.0](/docs/pg_secured/cis/pg14_V1.0.0.html) - paragraph 3.2
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::postgresql_audit_extension_pgaudit_is_enabled: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::postgresql_audit_extension_pgaudit_is_enabled::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `postgresql_audit_extension_pgaudit_is_enabled` to the array value `pg_secured::skip_list` in your hiera data.
#
# @param title
#    The instance to apply the control to.
#    All controls need an instance to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'instance':}
#    ```
#    In this example, the string `instance` is the instance to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::postgresql_audit_extension_pgaudit_is_enabled () {
  if $facts['pg_major_version'] != undef {
    $audit_version = case $facts['pg_major_version'] {
      '15': { '17' }
      '14': { '16' }
      '13': { '15' }
      '12': { '14' }
      '11': { '13' }
      '10': { '12' }
      default: {
        fail 'Unsupported postgres version'
      }
    }

    pg_secured_setup { "postgresql_audit_extension_pgaudit_is_enabled on ${title}":
      ensure => 'present',
    }

    -> package { "pgaudit${audit_version}_${facts['pg_major_version']}":
      ensure => 'present',
    }
  } else {
    warning 'Postgres version not (yet) known. Skipping this control for now'
  }
}
