#
# pg_secured::controls::ssl_is_enabled_and_configured_correctly
#
# @summary SSL on a PostgreSQL server should be enabled (set to on) and configured to encrypt TCP traffic to and from the server.
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/pg_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 6.8
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 6.8
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 6.8
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 6.8
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::ssl_is_enabled_and_configured_correctly: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::ssl_is_enabled_and_configured_correctly::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `ssl_is_enabled_and_configured_correctly` to the array value `pg_secured::skip_list` in your hiera data.
#
# @param title
#    The instance to apply the control to.
#    All controls need an instance to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'instance':}
#    ```
#    In this example, the string `instance` is the instance to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::ssl_is_enabled_and_configured_correctly {
  #
  # TODO: Make parameters for certificate and key file 
  pg_secured_setup { "ssl_is_enabled_and_configured_correctly on ${title}":
    ensure => 'present',
  }

  package { 'openssl':
    ensure => 'present',
  }

  -> pg_secured::internal::set_parameter { "ssl@${title}":
    value => 'on',
  }

  -> pg_secured::internal::set_parameter { "ssl_ciphers@${title}":
    value => 'HIGH:MEDIUM:+3DES:!aNULL',
  }

  -> pg_secured::internal::set_parameter { "ssl_cert_file@${title}":
    value => 'server.crt',
  }

  -> pg_secured::internal::set_parameter { "ssl_key_file@${title}":
    value => 'server.key',
  }

  -> pg_secured::internal::set_parameter { "password_encryption@${title}":
    value => 'scram-sha-256',
  }
}
