#
# pg_secured::controls::systemd_service_files_are_enabled
#
# @summary Confirm, and correct if necessary, the PostgreSQL systemd service is enabled.
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/pg_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 1.4
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 1.4
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 1.4
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 1.2
# - [Postgres Database 14 CIS V1.0.0](/docs/pg_secured/cis/pg14_V1.0.0.html) - paragraph 1.2
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::systemd_service_files_are_enabled: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::systemd_service_files_are_enabled::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `systemd_service_files_are_enabled` to the array value `pg_secured::skip_list` in your hiera data.
#
# @param title
#    The instance to apply the control to.
#    All controls need an instance to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'instance':}
#    ```
#    In this example, the string `instance` is the instance to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::systemd_service_files_are_enabled (
  String[1] $service_name = pg_secured::lookup_setting('service_name', "postgresql-${facts['pg_major_version']}")
) {
  if $facts['pg_major_version'] != undef {
    pg_secured_setup { "systemd_service_files_are_enabled on ${title}":
      ensure => 'present',
    }

    resource_value { "Service[${service_name}]ensure":
      value          => 'running',
      allow_create   => true,
      allow_redefine => true,
      ensure_value   => 'running',
      require        => Pg_secured_setup["systemd_service_files_are_enabled on ${title}"],
    }

    resource_value { "Service[${service_name}]enable":
      value          => true,
      allow_create   => true,
      allow_redefine => true,
      ensure_value   => 'running',
      require        => Pg_secured_setup["systemd_service_files_are_enabled on ${title}"],
    }
  } else {
    warning 'Postgres version not (yet) known. Skipping this control for now'
  }
}
